
# Type: identifier type


A string that is intended to uniquely identify a thing May be URI in full or compact (CURIE) form

URI: [ex:IdentifierType](http://example.org/mappings/IdentifierType)

|  |  |  |
| --- | --- | --- |
| Parent type | | [String](types/String.md) |
| Root (builtin) type | | **str** |
